@@ -3,7 +3,7 @@ from dataclasses import dataclass
 from typing import Any, TypeVar
 
 from dbt.adapters.base.column import Column
-from dbt.exceptions import RuntimeException
+from dbt.exceptions import DbtRuntimeError
 
 Self = TypeVar('Self', bound='ClickHouseColumn')
 
@@ -13,8 +13,8 @@ class ClickHouseColumn(Column):
     TYPE_LABELS = {
         'STRING': 'String',
         'TIMESTAMP': 'DateTime',
-        'FLOAT': 'Float64',
-        'INTEGER': 'Int64',
+        'FLOAT': 'Float32',
+        'INTEGER': 'Int32',
     }
     is_nullable: bool = False
     _brackets_regex = re.compile(r'^(Nullable|LowCardinality)\((.*)\)$')
@@ -96,7 +96,7 @@ class ClickHouseColumn(Column):
 
     def string_size(self) -> int:
         if not self.is_string():
-            raise RuntimeException('Called string_size() on non-string field!')
+            raise DbtRuntimeError('Called string_size() on non-string field!')
 
         if not self.dtype.lower().startswith('fixedstring') or self.char_size is None:
             return 256
@@ -109,7 +109,7 @@ class ClickHouseColumn(Column):
 
     @classmethod
     def numeric_type(cls, dtype: str, precision: Any, scale: Any) -> str:
-        return dtype
+        return f'Decimal({precision}, {scale})'
 
     def literal(self, value):
         return f'to{self.dtype}({value})'
