@@ -16,18 +16,16 @@
   {%- set column_override = model['config'].get('column_types', {}) -%}
   {%- set quote_seed_column = model['config'].get('quote_columns', None) -%}
 
-  {{ log}}
   {% set sql %}
     create table {{ this.render() }} (
       {%- for col_name in agate_table.column_names -%}
         {%- set inferred_type = adapter.convert_type(agate_table, loop.index0) -%}
         {%- set type = column_override.get(col_name, inferred_type) -%}
-        {{ log('SEED TYPE ' ~ type, True) }}
         {%- set column_name = (col_name | string) -%}
           {{ adapter.quote_seed_column(column_name, quote_seed_column) }} {{ type }} {%- if not loop.last -%}, {%- endif -%}
       {%- endfor -%}
     )
-    {{ engine_clause(label='engine') }}
+    {{ engine_clause() }}
     {{ order_cols(label='order by') }}
     {{ partition_cols(label='partition by') }}
   {% endset %}
